@@ -1,7 +1,7 @@
 package snaked;
 
 use vars qw($VERSION);
-$VERSION = '0.13';
+$VERSION = '0.14';
 
 use strict;
 use warnings;
@@ -369,22 +369,25 @@ __END__
 
 =head1 NAME
 
-snaked - cron as it should be.
+snaked - cron as it should be. Or shouldn't? L<Please vote!|http://www.kohts.com/cron-5/vote/>
 
 =head1 SYNOPSIS
 
   # import old cron jobs (TO BE IMPLEMENTED)
   snaked --import-crontabs
 
+  # generate sample configuration (discussed below) in /etc/snaked
+  snaked --sample-config
+
   # check which jobs are configured
-  snaked --show-jobs
+  snaked --show-config
 
-  # rock with snake
+  # run in the foreground (CTRL-C to exit)
+  snaked --debug
+
+  # run in the background
   snaked --daemon
 
-  # (and do not forget to stop old cron
-  # so your jobs are not run twice)
-
 =head1 DESCRIPTION
 
 B<snaked> is a job scheduler, just like cron,
@@ -432,6 +435,15 @@ and snaked job schedule format which specifies how often
 the jobs is run in seconds, making it possible to run job
 even once a second!
 
+=head2 run from any user, root is not required
+
+Although configuration example below shows snaked run from root,
+this is not a requirement. snaked doesn't require any specific
+super-user privileges. Just specify configuration path
+(with --cfg parameter) accessible by snaked (that's why
+default log path for example points to /tmp) and run it
+from any user.
+
 =head1 CONFIGURATION EXAMPLE
 
 snaked configuration is a directory which contains
@@ -455,8 +467,8 @@ stored in a separate file:
   |       `-- execution_interval
   `-- log
 
-Above shown configuration defines admin_email
-for the snaked instance (optional, defaults to root)
+Above shown configuration (run "snaked --sample-config" from root to get it)
+defines admin_email for the snaked instance (optional, defaults to root)
 and log file path (optional, defaults to /tmp/snaked.log):
 
   testing18:/etc/snaked# cat admin_email
@@ -464,10 +476,12 @@ and log file path (optional, defaults to /tmp/snaked.log):
   testing18:/etc/snaked# cat log
   /var/log/snaked/snaked.log
 
-There are three jobs named every_hour, every_ten_seconds
-and fast_job. All of them contain cmd file -- an executable
-which is run by snaked (this can be any executable
-allowed by underlying operating system):
+There are three jobs named every_hour, every_ten_seconds and fast_job
+which append the result of 'uptime' command to /tmp/snaked_every_hour,
+/tmp/snaked_ten_seconds and /tmp/snaked_fast_job. This is done by
+running 'cmd' file which resides in job directory -- shell script
+in sample configuration, this can be any executable allowed
+by underlying operating system:
 
   testing18:/etc/snaked/jobs/every_hour# ls -l cmd
   -rwxr-xr-x 1 root root 0 2010-07-07 00:24 cmd
@@ -539,6 +553,13 @@ Optional. Filename of the pidfile where snaked stores
 the pid of its main process. Defaults to nothing,
 which does not generate any pidfile.
 
+=item spool_directory
+
+Optional. Directory which is used to write detailed status
+and debugging information (if configured).
+
+Defaults to /tmp/snaked.spool__etc_snaked
+
 =back
 
 =head1 JOB OPTIONS
@@ -547,7 +568,7 @@ which does not generate any pidfile.
 
 =item admin_email
 
-Optional. Where toe send emails about failures of this job.
+Optional. Where to send emails about failures of this job.
 Defaults to global admin_email option (and overrides it). 
 
 =item cmd
@@ -555,6 +576,11 @@ Defaults to global admin_email option (and overrides it).
 Mandatory. Executable with correct file permissions (executable bit on)
 which is allowed by underlying operating system. Can be shell script or binary.
 
+=item disabled
+
+Optional. Existing file specifies that this job should not be run
+(see also --enable-jobs and --disable-jobs command line parameters)
+
 =item execution_interval, execution_schedule
 
 Only one parameter, execution_interval or execution_schedule, is allowed
@@ -590,8 +616,8 @@ which turns the feature off.
 =item conflicts
 
 Optional. Space/line separated list of job identifiers
-which should not be run while this job is run. If any
-job from this list is currently being executed
+which should wait while this job is running. If any job
+from this list is currently being executed
 then the job owning the option will not be executed.
 Defaults to nothing, allowing the job to be run
 independently of the status of any other job.
@@ -605,6 +631,92 @@ waiting for the conflicting jobs.
 
 =back
 
+=head1 DAEMON COMMAND-LINE PARAMETERS
+
+=over 4
+
+=item --daemon or --debug [--cfg PATH]
+
+Two main (and mutually exclusive) command-line parameters are
+--daemon (run in background) and --debug (run in foreground). 
+
+--cfg option specifies snaked configuration which is to be used
+for this snaked copy (defaults to /etc/snaked)
+
+You can run several independent daemons with different configurations.
+
+=item --stop [--cfg PATH] [--wait]
+
+Request snaked to be stopped. With --wait option this request
+will not return until snaked is actually stopped.
+
+=item --configure [--cfg PATH]
+
+Request snaked to reread configuration.
+
+=item --restart [--cfg PATH]
+
+Request snaked to restart. With --wait option this request
+will not return until snaked is actually restarted.
+
+=item --status [--cfg PATH]
+
+Check whether snaked runs.
+
+This is done by traversing all the running processes
+and finding those which name matches snaked --cfg PATH.
+If --cfg parameter is not specified then PATH
+defaults to /etc/snaked
+
+=item --detailed-status [--cfg PATH]
+
+Dumps detailed state information into spool_directory.
+
+=item --version
+
+Show snaked version.
+
+=item --show-config [--cfg PATH]
+
+Dumps the configuration.
+
+=item --enable-jobs <JOB_LIST> [--cfg PATH]
+
+For every job in JOB_LIST (space separated) remove special
+'disabled' file from job directory and request snaked to reread
+configuration.
+
+=item --disable-jobs <JOB_LIST> [--cfg PATH]
+
+For every job in JOB_LIST (space separated) add special
+'disabled' file tojob directory and request snaked to reread
+configuration.
+
+=item --add-job <JOB_NAME> --execution_interval N --cmd BASH_TEXT [--cfg PATH]
+
+Add job named JOB_NAME to the snaked configuration pointed to by PATH
+(defaults to /etc/snaked). execution_interval is set to N, cmd is set
+to BASH_TEXT (protect shell special characters with quotes).
+
+Other job parameters can be specified as well.
+
+=item --delete-jobs <JOB_LIST> [--cfg PATH]
+
+Delete jobs from snaked configuration pointed to by PATH (defaults
+to /etc/snaked). This command does actually removes whole job directory,
+consider using --disable-jobs <JOB_LIST> as it is safer.
+
+=item --modify-job <JOB_NAME> <--parameter> <value> [--cfg PATH]
+
+Replace current value of parameter of the specified job with new value
+in the snaked configuration pointed to by PATH (defaults to /etc/snaked)
+
+=item --sample-config [PATH]
+
+Populate PATH or /etc/snaked (must not exist) with sample configuration
+
+=back
+
 =head1 CREDITS
 
 Thanks to the whole Yandex team and personally to the following people (in alphabetic order):
@@ -626,11 +738,11 @@ for their bug reports, suggestions and contributions.
 
 =head1 AUTHORS
 
-Petya Kohts E<lt>petya@kohts.ruE<gt>
+Petya Kohts E<lt>petya@kohts.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2009 - 2012 Petya Kohts.
+Copyright 2009 - 2013 Petya Kohts.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
